package com.ruoyi.buyerapi.service;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerIntangibleAssets;

/**
 * 无形资产摊销记录Service接口
 * 
 * @author ruoyi
 * @date 2022-09-22
 */
public interface IBuyerIntangibleAssetsService 
{
    /**
     * 查询无形资产摊销记录
     * 
     * @param id 无形资产摊销记录主键
     * @return 无形资产摊销记录
     */
    public BuyerIntangibleAssets selectBuyerIntangibleAssetsById(String id);

    /**
     * 查询无形资产摊销记录列表
     * 
     * @param buyerIntangibleAssets 无形资产摊销记录
     * @return 无形资产摊销记录集合
     */
    public List<BuyerIntangibleAssets> selectBuyerIntangibleAssetsList(BuyerIntangibleAssets buyerIntangibleAssets);

    /**
     * 统计无形资产摊销记录列表
     *
     * @param buyerIntangibleAssets 无形资产摊销记录
     * @return 无形资产摊销记录集合
     */
    public List<BuyerIntangibleAssets> selectStatistBuyerIntangibleAssetsList(BuyerIntangibleAssets buyerIntangibleAssets);

    /**
     * 新增无形资产摊销记录
     * 
     * @param buyerIntangibleAssets 无形资产摊销记录
     * @return 结果
     */
    public int insertBuyerIntangibleAssets(BuyerIntangibleAssets buyerIntangibleAssets);

    /**
     * 修改无形资产摊销记录
     * 
     * @param buyerIntangibleAssets 无形资产摊销记录
     * @return 结果
     */
    public int updateBuyerIntangibleAssets(BuyerIntangibleAssets buyerIntangibleAssets);

    /**
     * 批量删除无形资产摊销记录
     * 
     * @param ids 需要删除的无形资产摊销记录主键集合
     * @return 结果
     */
    public int deleteBuyerIntangibleAssetsByIds(String[] ids);

    /**
     * 删除无形资产摊销记录信息
     * 
     * @param id 无形资产摊销记录主键
     * @return 结果
     */
    public int deleteBuyerIntangibleAssetsById(String id);
}
